﻿using System;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace DisplayASimpleMapForMvc.Controllers
{
    public class IndexController : Controller
    {
        public ActionResult Index()
        {
            Map map = new Map("Map1",
               new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
               new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));
            map.MapUnit = GeographyUnit.Meter;

            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetLatLongParametersString();
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
            proj4.Open();

            GoogleOverlay googleOverlay = new GoogleOverlay();
            map.CustomOverlays.Add(googleOverlay);

            LayerOverlay dynamicOverlay = new LayerOverlay();
            dynamicOverlay.IsBaseOverlay = false;

            ShapeFileFeatureLayer polygonLayer = new ShapeFileFeatureLayer(Server.MapPath("~/Data/USStates.shp"));
            polygonLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            polygonLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            polygonLayer.Open();
            polygonLayer.FeatureSource.Projection = proj4;

            ShapeFileFeatureLayer pointLayer = new ShapeFileFeatureLayer(Server.MapPath("~/Data/MajorCities.shp"));
            pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital1;
            pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            pointLayer.Open();
            pointLayer.FeatureSource.Projection = proj4;


            dynamicOverlay.Layers.Add(polygonLayer);
            dynamicOverlay.Layers.Add(pointLayer);
            map.CustomOverlays.Add(dynamicOverlay);

            map.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
            return View(map);
        }
    }
}
